@@ -141,6 +141,7 @@ describe 'horizon' do
           :create_image_defaults          => {'image_visibility' => 'private'},
           :password_retrieve              => true,
           :enable_secure_proxy_ssl_header => true,
+          :secure_proxy_addr_header       => 'HTTP_X_FORWARDED_FOR',
         })
       end
 
@@ -150,6 +151,7 @@ describe 'horizon' do
           "SITE_BRANDING = 'mysite'",
           "ALLOWED_HOSTS = ['some.host.tld', ]",
           "SECURE_PROXY_SSL_HEADER = ('HTTP_X_FORWARDED_PROTO', 'https')",
+          "SECURE_PROXY_ADDR_HEADER = 'HTTP_X_FORWARDED_FOR'",
           'CSRF_COOKIE_SECURE = True',
           'SESSION_COOKIE_SECURE = True',
           'SESSION_COOKIE_HTTPONLY = True',
@@ -214,9 +216,11 @@ describe 'horizon' do
           'COMPRESS_OFFLINE = False',
           "FILE_UPLOAD_TEMP_DIR = '/var/spool/horizon'",
           "OVERVIEW_DAYS_RANGE = 1",
+          'DISALLOW_IFRAME_EMBED = True',
         ])
       end
 
+      it { is_expected.to contain_file(platforms_params[:conf_d_dir]).with_ensure('directory') }
       it { is_expected.not_to contain_file(platforms_params[:config_file]).that_notifies('Exec[refresh_horizon_django_cache]') }
       it { is_expected.not_to contain_file(platforms_params[:config_file]).that_notifies('Exec[refresh_horizon_django_compress]') }
 
@@ -296,7 +300,7 @@ describe 'horizon' do
 
       it {
         is_expected.to contain_package('python-memcache').with(
-          :tag    => ['openstack', 'horizon-package'],
+          :tag    => ['openstack'],
           :name   => platforms_params[:memcache_package],
          )
       }
@@ -344,21 +348,23 @@ describe 'horizon' do
     context 'with ssl enabled' do
       before do
         params.merge!({
-          :listen_ssl   => true,
-          :servername   => 'some.host.tld',
-          :horizon_cert => '/etc/pki/tls/certs/httpd.crt',
-          :horizon_key  => '/etc/pki/tls/private/httpd.key',
-          :horizon_ca   => '/etc/pki/tls/certs/ca.crt',
+          :listen_ssl        => true,
+          :servername        => 'some.host.tld',
+          :horizon_cert      => '/etc/pki/tls/certs/httpd.crt',
+          :horizon_key       => '/etc/pki/tls/private/httpd.key',
+          :horizon_ca        => '/etc/pki/tls/certs/ca.crt',
+          :ssl_verify_client => 'optional',
         })
       end
 
       it 'configures apache' do
         is_expected.to contain_class('horizon::wsgi::apache').with({
-          :bind_address => nil,
-          :listen_ssl   => true,
-          :horizon_cert => '/etc/pki/tls/certs/httpd.crt',
-          :horizon_key  => '/etc/pki/tls/private/httpd.key',
-          :horizon_ca   => '/etc/pki/tls/certs/ca.crt',
+          :bind_address      => nil,
+          :listen_ssl        => true,
+          :horizon_cert      => '/etc/pki/tls/certs/httpd.crt',
+          :horizon_key       => '/etc/pki/tls/private/httpd.key',
+          :horizon_ca        => '/etc/pki/tls/certs/ca.crt',
+          :ssl_verify_client => 'optional',
         })
       end
     end
@@ -575,16 +581,16 @@ describe 'horizon' do
       end
     end
 
-    context 'with disallow iframe embed enabled' do
+    context 'with disallow iframe embed disabled' do
       before do
         params.merge!({
-                        :disallow_iframe_embed => true
+                        :disallow_iframe_embed => false
                       })
       end
 
       it 'disallow_iframe_embed is configured' do
         verify_concat_fragment_contents(catalogue, 'local_settings.py', [
-                                          'HORIZON_CONFIG["disallow_iframe_embed"] = True',
+                                          'DISALLOW_IFRAME_EMBED = False',
                                         ])
       end
     end
@@ -751,6 +757,7 @@ describe 'horizon' do
         when 'Debian'
           if facts[:os_package_type] == 'debian'
             { :config_file      => '/etc/openstack-dashboard/local_settings.py',
+              :conf_d_dir       => '/etc/openstack-dashboard/local_settings.d',
               :package_name     => 'openstack-dashboard-apache',
               :root_url         => '/horizon',
               :root_path        => '/var/lib/openstack-dashboard',
@@ -758,6 +765,7 @@ describe 'horizon' do
             }
           else
             { :config_file      => '/etc/openstack-dashboard/local_settings.py',
+              :conf_d_dir       => '/etc/openstack-dashboard/local_settings.d',
               :package_name     => 'openstack-dashboard',
               :root_url         => '/horizon',
               :root_path        => '/var/lib/openstack-dashboard',
@@ -765,12 +773,33 @@ describe 'horizon' do
             }
           end
         when 'RedHat'
-          { :config_file      => '/etc/openstack-dashboard/local_settings',
-            :package_name     => 'openstack-dashboard',
-            :root_url         => '/dashboard',
-            :root_path        => '/usr/share/openstack-dashboard',
-            :memcache_package => 'python-memcached',
-          }
+          if facts[:operatingsystem] == 'Fedora'
+            { :config_file      => '/etc/openstack-dashboard/local_settings',
+              :conf_d_dir       => '/etc/openstack-dashboard/local_settings.d',
+              :package_name     => 'openstack-dashboard',
+              :root_url         => '/dashboard',
+              :root_path        => '/usr/share/openstack-dashboard',
+              :memcache_package => 'python3-memcached',
+            }
+          else
+            if facts[:operatingsystemmajrelease] > '7'
+              { :config_file      => '/etc/openstack-dashboard/local_settings',
+                :conf_d_dir       => '/etc/openstack-dashboard/local_settings.d',
+                :package_name     => 'openstack-dashboard',
+                :root_url         => '/dashboard',
+                :root_path        => '/usr/share/openstack-dashboard',
+                :memcache_package => 'python3-memcached',
+              }
+            else
+              { :config_file      => '/etc/openstack-dashboard/local_settings',
+                :conf_d_dir       => '/etc/openstack-dashboard/local_settings.d',
+                :package_name     => 'openstack-dashboard',
+                :root_url         => '/dashboard',
+                :root_path        => '/usr/share/openstack-dashboard',
+                :memcache_package => 'python-memcached',
+              }
+            end
+          end
         end
       end
 
