@@ -30,6 +30,7 @@ describe 'horizon::wsgi::apache' do
       it { should contain_apache__vhost('horizon_vhost').with(
         :servername                  => 'some.host.tld',
         :access_log_file             => 'horizon_access.log',
+        :access_log_format           => false,
         :error_log_file              => 'horizon_error.log',
         :priority                    => '15',
         :serveraliases               => ['some.host.tld'],
@@ -56,10 +57,11 @@ describe 'horizon::wsgi::apache' do
     context 'with overridden parameters' do
       before do
         params.merge!({
-          :priority       => '10',
-          :redirect_type  => 'temp',
-          :wsgi_processes => '13',
-          :wsgi_threads   => '3'
+          :priority          => '10',
+          :redirect_type     => 'temp',
+          :wsgi_processes    => '13',
+          :wsgi_threads      => '3',
+          :access_log_format => 'common',
         })
       end
 
@@ -74,6 +76,7 @@ describe 'horizon::wsgi::apache' do
       it { should contain_apache__vhost('horizon_vhost').with(
         :servername                  => 'some.host.tld',
         :access_log_file             => 'horizon_access.log',
+        :access_log_format           => 'common',
         :error_log_file              => 'horizon_error.log',
         :priority                    => params[:priority],
         :serveraliases               => ['some.host.tld'],
@@ -122,11 +125,12 @@ describe 'horizon::wsgi::apache' do
     context 'with ssl enabled' do
       before do
         params.merge!({
-          :listen_ssl   => true,
-          :ssl_redirect => true,
-          :horizon_cert => '/etc/pki/tls/certs/httpd.crt',
-          :horizon_key  => '/etc/pki/tls/private/httpd.key',
-          :horizon_ca   => '/etc/pki/tls/certs/ca.crt',
+          :listen_ssl        => true,
+          :ssl_redirect      => true,
+          :horizon_cert      => '/etc/pki/tls/certs/httpd.crt',
+          :horizon_key       => '/etc/pki/tls/private/httpd.key',
+          :horizon_ca        => '/etc/pki/tls/certs/ca.crt',
+          :ssl_verify_client => 'optional',
         })
       end
 
@@ -135,6 +139,7 @@ describe 'horizon::wsgi::apache' do
       it { should contain_apache__vhost('horizon_ssl_vhost').with(
         :servername             => 'some.host.tld',
         :access_log_file        => 'horizon_ssl_access.log',
+        :access_log_format      => false,
         :error_log_file         => 'horizon_ssl_error.log',
         :priority               => '15',
         :serveraliases          => ['some.host.tld'],
@@ -144,6 +149,7 @@ describe 'horizon::wsgi::apache' do
         :ssl_cert               => '/etc/pki/tls/certs/httpd.crt',
         :ssl_key                => '/etc/pki/tls/private/httpd.key',
         :ssl_ca                 => '/etc/pki/tls/certs/ca.crt',
+        :ssl_verify_client      => 'optional',
         :redirectmatch_status   => 'permanent',
         :redirectmatch_regexp   => '^/$',
         :redirectmatch_dest     => platforms_params[:root_url],
@@ -158,6 +164,7 @@ describe 'horizon::wsgi::apache' do
       it { should contain_apache__vhost('horizon_vhost').with(
         :servername             => 'some.host.tld',
         :access_log_file        => 'horizon_access.log',
+        :access_log_format      => false,
         :error_log_file         => 'horizon_error.log',
         :priority               => '15',
         :serveraliases          => ['some.host.tld'],
